@@ -38,6 +38,9 @@
 /* path of device file */
 #define FMRADIO_DEVICE "/dev/radio1"
 
+/* path of sysfs interface */
+#define FMRADIO_SYSFS "/sys/class/i2c-adapter/i2c-3/3-0022"
+
 /* timeout intervals in seconds between watchdog iterations */
 #define WATCHDOG_TIMEOUT            10
 
